from setuptools import setup

setup(name='savimonty_distributions',
      version='0.1',
      description='Probability Distributions',
      packages=['savimonty_distributions'],
      zip_safe=False)
